# Scripts for finding unused modules, deprecating modules, and removing deprecated modules

## Finding unused modules

The module usage information is stored in a database, and in order to query it you first need to have these scripts available:
https://github.com/TACC/Lmod/tree/master/contrib/tracking_module_usage

You will have to add a file `pg_module_usage_db.conf` that contains:
```
[MYSQL]
host = <database host>
user = <database user>
passwd = <base64 encoded database password>
db = <database name>
```

Now use the script to dump all the used modules between a given start and end date, e.g. for 2020:
```
./analyzeLmodDB --dbname pg_module_usage --start 2020-01-01 --end 2021-01-01 --sqlPattern "/software/%" counts > usage_20200101-20201231.txt
```

We also need a dump of all available modules on the system:
```
module --redirect -t avail | grep -v "\/$" | grep -v "\:$" | grep -v "\@" > all.txt
```

Finally, run the included `find_used.py` script to find the set difference between all modules and the used modules,
i.e. to obtain the unused modules:
```
./find_used.py all.txt usage_20200101-20201231.txt > unused_20200101-20201231.txt
```

### Manually deprecate modules
If you need to manually add some (used) modules that you want to deprecate,
you can easily do so by creating an additional file (e.g. `extra.txt`) that contains one module name per line,
and then concatenate both files by running:
```
cat extra.txt unused_20200101-20201231.txt > deprecate.txt
```

## Deprecate modules

In order to deprecate modules, we need to add a `lmodadmin.txt` to each `/apps/<infrastructure>/lmod` directory.
This file should have the following for each module that you want to deprecate:
```
nameOfModule/version:
	Deprecation message
	Indentation required
	Message can be multi-line

```

This file can be generated by putting your deprecation message in a separate file, e.g. `deprecation_message.txt`
(make sure to prefix all lines by a tab!), and running:
```
./make_siteadmin_file.py deprecate.txt deprecation_message.txt > lmodadmin.txt
```
Here `deprecate.txt` is the file containing the names of the modules that should be deprecated.
The resulting `lmodadmin.txt` can be copied to the aforementioned directories.

## Removing deprecated modules
Removing modules can be a bit tricky, as the same module is usually available for multiple architectures,
and may have either a TCL module file (without extension) or a LUA module file (with a .lua extension).
The included script `create_module_removal_script.sh` will not remove any modules itself (and hence, it should always be safe to run this script),
but instead it will generate a Bash script that can do the removal by for a given list of modules.

The script expects a file with modules to be removed (one per line), i.e. it can run in the following way:
```
./create_module_removal_script.sh deprecate.txt > remove_deprecated_modules.sh
```

The `remove_deprecated_modules.sh` contains the actual commands that will have to be run in order to remove your deprecated modules.
Note that it removes the modules by moving both the installations and module files to a trash folder.
After you have made sure that the generated script/commands are fine, simply execute them to do the cleanup.
